<?php

declare(strict_types=1);

namespace Brick\Math;

class RoundingMode
{
    public const UNNECESSARY = 'unnecessary';
    public const UP = 'up';
    public const DOWN = 'down';
    public const CEILING = 'ceiling';
    public const FLOOR = 'floor';
    public const HALF_UP = 'half_up';
    public const HALF_DOWN = 'half_down';
    public const HALF_CEILING = 'half_ceiling';
    public const HALF_FLOOR = 'half_floor';
    public const HALF_EVEN = 'half_even';
}
