caption,
td,
th {
	text-align: right;
}

.menu-item-has-children .dropdown-menu-toggle {
	float: left !important;
}

.main-navigation li {
	float: right;
	text-align: right;
}

.main-navigation li.search-item,
.nav-aligned-right.nav-below-header .main-navigation .menu > li.search-item {
	float: left;
}

.nav-left-sidebar .main-navigation li.search-item.current-menu-item,
.nav-right-sidebar .main-navigation li.search-item.current-menu-item {
	float: left;
}

.rtl.nav-aligned-left .main-navigation .menu > li {
	float: none;
	display: inline-block;
}

.rtl.nav-aligned-left .main-navigation ul {
	letter-spacing: -0.31em;
	font-size: 1em;
}

.rtl.nav-aligned-left .main-navigation ul li {
	letter-spacing: normal;
}

.rtl.nav-aligned-left .main-navigation {
	text-align: left;
}

.sidebar .menu-item-has-children .dropdown-menu-toggle,
nav ul ul .menu-item-has-children .dropdown-menu-toggle {
	float: left;
}

.comment-meta .avatar {
	float: right;
	margin-left: 10px;
}

.page-header .avatar {
	float: right;
	margin-left: 1.5em;
}

.header-widget {
	float: left;
}

.sf-menu > li.menu-item-float-right {
	float: left !important;
}

.slideout-navigation .menu-item-has-children .dropdown-menu-toggle {
	float: left;
}

.dropdown-click #generate-slideout-menu .slideout-menu .menu-item-has-children > a:first-child,
.slideout-desktop.dropdown-hover #generate-slideout-menu .slideout-menu .menu-item-has-children > a:first-child {
	padding-left: 0;
}

.comment .children {
	padding-right: 30px;
	border-right: 1px solid rgba(0, 0, 0, 0.05);
}

.main-navigation .main-nav ul li.menu-item-has-children > a,
.secondary-navigation .main-nav ul li.menu-item-has-children > a {
	padding-left: 0;
}

nav:not(.toggled) ul ul .menu-item-has-children .dropdown-menu-toggle {
	padding-left: 15px;
}

nav:not(.toggled) .menu-item-has-children .dropdown-menu-toggle {
	padding-right: 10px;
}

.main-navigation ul,
.menu-toggle li.search-item {
	padding-right: 0;
}

ol,
ul {
	margin: 0 3em 1.5em 0;
}

li > ol,
li > ul {
	margin-right: 1.5em;
}

.menu-toggle .mobile-menu {
	margin-right: 5px;
	margin-left: 0;
}

.widget_categories .children {
	margin-right: 1.5em;
}

.widget_nav_menu ul ul,
.widget_pages ul ul {
	margin-right: 1em;
}

.cat-links:before,
.comments-link:before,
.nav-next .next:before,
.nav-previous .prev:before,
.tags-links:before {
	margin-left: 0.6em;
	margin-right: 0;
}

.menu-toggle,
.nav-search-enabled .main-navigation .menu-toggle {
	text-align: right;
}

.main-navigation .mobile-bar-items {
	float: left;
	left: 0;
	right: auto;
}

.rtl .navigation-search {
	left: auto;
	right: -999999px;
}

.rtl .navigation-search.nav-search-active {
	right: 0;
}

.rtl .footer-bar .widget_nav_menu li {
	direction: rtl;
	float: right;
}

.main-navigation.toggled .main-nav li {
	text-align: right !important;
}

.entry-meta .gp-icon {
	margin-right: 0;
	margin-left: 0.6em;
}

@media (max-width: 768px) {
	.rtl .mobile-bar-items {
		position: absolute;
		left: 0;
		top: 0;
	}
}

@media (min-width: 768px) {
	.inside-footer-widgets > div {
		float: right;
	}
}
