<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInit9801abce1960fa4b71d115bb31b779c7
{
    public static $prefixLengthsPsr4 = array (
        'S' => 
        array (
            'Symfony\\Polyfill\\Php80\\' => 23,
            'Symfony\\Polyfill\\Intl\\Normalizer\\' => 33,
            'Symfony\\Polyfill\\Ctype\\' => 23,
        ),
        'R' => 
        array (
            'Rowbot\\URL\\' => 11,
            'Rowbot\\Punycode\\' => 16,
            'Rowbot\\Idna\\Resource\\' => 21,
            'Rowbot\\Idna\\' => 12,
        ),
        'P' => 
        array (
            'Psr\\Log\\' => 8,
            'Psr\\EventDispatcher\\' => 20,
        ),
        'B' => 
        array (
            'Brick\\Math\\' => 11,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'Symfony\\Polyfill\\Php80\\' => 
        array (
            0 => __DIR__ . '/../..' . '/DataLiberation/vendor-patched/symfony/polyfill-php80/src',
        ),
        'Symfony\\Polyfill\\Intl\\Normalizer\\' => 
        array (
            0 => __DIR__ . '/../..' . '/DataLiberation/vendor-patched/symfony/polyfill-intl-normalizer/src',
        ),
        'Symfony\\Polyfill\\Ctype\\' => 
        array (
            0 => __DIR__ . '/../..' . '/DataLiberation/vendor-patched/symfony/polyfill-ctype/src',
        ),
        'Rowbot\\URL\\' => 
        array (
            0 => __DIR__ . '/../..' . '/DataLiberation/vendor-patched/rowbot/url/src',
        ),
        'Rowbot\\Punycode\\' => 
        array (
            0 => __DIR__ . '/../..' . '/DataLiberation/vendor-patched/rowbot/punycode/src',
        ),
        'Rowbot\\Idna\\Resource\\' => 
        array (
            0 => __DIR__ . '/../..' . '/DataLiberation/vendor-patched/rowbot/idna/resources',
        ),
        'Rowbot\\Idna\\' => 
        array (
            0 => __DIR__ . '/../..' . '/DataLiberation/vendor-patched/rowbot/idna/src',
        ),
        'Psr\\Log\\' => 
        array (
            0 => __DIR__ . '/../..' . '/DataLiberation/vendor-patched/psr/log/src',
        ),
        'Psr\\EventDispatcher\\' => 
        array (
            0 => __DIR__ . '/../..' . '/DataLiberation/vendor-patched/psr/event-dispatcher/src',
        ),
        'Brick\\Math\\' => 
        array (
            0 => __DIR__ . '/../..' . '/DataLiberation/vendor-patched/brick/math/src',
        ),
    );

    public static $classMap = array (
        'Composer\\InstalledVersions' => __DIR__ . '/..' . '/composer/InstalledVersions.php',
        'WordPress\\ByteStream\\ByteStreamException' => __DIR__ . '/../..' . '/ByteStream/class-bytestreamexception.php',
        'WordPress\\ByteStream\\NotEnoughDataException' => __DIR__ . '/../..' . '/ByteStream/class-notenoughdataexception.php',
        'WordPress\\ByteStream\\ReadStream\\BaseByteReadStream' => __DIR__ . '/../..' . '/ByteStream/ReadStream/class-basebytereadstream.php',
        'WordPress\\ByteStream\\ReadStream\\ByteReadStream' => __DIR__ . '/../..' . '/ByteStream/ReadStream/interface-bytereadstream.php',
        'WordPress\\ByteStream\\ReadStream\\FileReadStream' => __DIR__ . '/../..' . '/ByteStream/ReadStream/class-filereadstream.php',
        'WordPress\\DataLiberation\\BlockMarkup\\BlockMarkupProcessor' => __DIR__ . '/../..' . '/DataLiberation/BlockMarkup/class-blockmarkupprocessor.php',
        'WordPress\\DataLiberation\\BlockMarkup\\BlockMarkupUrlProcessor' => __DIR__ . '/../..' . '/DataLiberation/BlockMarkup/class-blockmarkupurlprocessor.php',
        'WordPress\\DataLiberation\\BlockMarkup\\BlockObject' => __DIR__ . '/../..' . '/DataLiberation/BlockMarkup/class-blockobject.php',
        'WordPress\\DataLiberation\\CSS\\CSSProcessor' => __DIR__ . '/../..' . '/DataLiberation/CSS/class-cssprocessor.php',
        'WordPress\\DataLiberation\\EntityReader\\EntityReader' => __DIR__ . '/../..' . '/DataLiberation/EntityReader/entity-reader.php',
        'WordPress\\DataLiberation\\EntityReader\\WXREntityReader' => __DIR__ . '/../..' . '/DataLiberation/EntityReader/class-wxrentityreader.php',
        'WordPress\\DataLiberation\\ImportEntity' => __DIR__ . '/../..' . '/DataLiberation/class-importentity.php',
        'WordPress\\DataLiberation\\URL\\CSSURLProcessor' => __DIR__ . '/../..' . '/DataLiberation/URL/class-cssurlprocessor.php',
        'WordPress\\DataLiberation\\URL\\ConvertedUrl' => __DIR__ . '/../..' . '/DataLiberation/URL/class-convertedurl.php',
        'WordPress\\DataLiberation\\URL\\URLInTextProcessor' => __DIR__ . '/../..' . '/DataLiberation/URL/class-urlintextprocessor.php',
        'WordPress\\DataLiberation\\URL\\WPURL' => __DIR__ . '/../..' . '/DataLiberation/URL/class-wpurl.php',
        'WordPress\\XML\\XMLAttributeToken' => __DIR__ . '/../..' . '/XML/class-xmlattributetoken.php',
        'WordPress\\XML\\XMLDecoder' => __DIR__ . '/../..' . '/XML/class-xmldecoder.php',
        'WordPress\\XML\\XMLElement' => __DIR__ . '/../..' . '/XML/class-xmlelement.php',
        'WordPress\\XML\\XMLProcessor' => __DIR__ . '/../..' . '/XML/class-xmlprocessor.php',
        'WordPress\\XML\\XMLUnsupportedException' => __DIR__ . '/../..' . '/XML/class-xmlunsupportedexception.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInit9801abce1960fa4b71d115bb31b779c7::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInit9801abce1960fa4b71d115bb31b779c7::$prefixDirsPsr4;
            $loader->classMap = ComposerStaticInit9801abce1960fa4b71d115bb31b779c7::$classMap;

        }, null, ClassLoader::class);
    }
}
