:root :where(figure.wp-block-gallery){
  display:block;
}
:root :where(figure.wp-block-gallery)>.blocks-gallery-caption{
  flex:0 0 100%;
}
:root :where(figure.wp-block-gallery)>.blocks-gallery-media-placeholder-wrapper{
  flex-basis:100%;
}
:root :where(figure.wp-block-gallery) .wp-block-image .components-notice.is-error{
  display:block;
}
:root :where(figure.wp-block-gallery) .wp-block-image .components-notice__content{
  margin:4px 0;
}
:root :where(figure.wp-block-gallery) .wp-block-image .components-notice__dismiss{
  position:absolute;
  right:5px;
  top:0;
}
:root :where(figure.wp-block-gallery) .block-editor-media-placeholder.is-appender .components-placeholder__label{
  display:none;
}
:root :where(figure.wp-block-gallery) .block-editor-media-placeholder.is-appender .block-editor-media-placeholder__button{
  margin-bottom:0;
}
:root :where(figure.wp-block-gallery) .block-editor-media-placeholder{
  margin:0;
}
:root :where(figure.wp-block-gallery) .block-editor-media-placeholder .components-placeholder__label{
  display:flex;
}
:root :where(figure.wp-block-gallery) .block-editor-media-placeholder figcaption{
  z-index:2;
}
:root :where(figure.wp-block-gallery) .components-spinner{
  left:50%;
  margin-left:-9px;
  margin-top:-9px;
  position:absolute;
  top:50%;
}
.gallery-settings-buttons .components-button:first-child{
  margin-right:8px;
}
.blocks-gallery-item figure:not(.is-selected):focus,.blocks-gallery-item img:focus{
  outline:none;
}
.blocks-gallery-item figure.is-selected:before{
  bottom:0;
  box-shadow:0 0 0 1px #fff inset, 0 0 0 3px var(--wp-admin-theme-color) inset;
  content:"";
  left:0;
  outline:2px solid #0000;
  pointer-events:none;
  position:absolute;
  right:0;
  top:0;
  z-index:1;
}
.blocks-gallery-item figure.is-transient img{
  opacity:.3;
}
.blocks-gallery-item .block-editor-media-placeholder{
  height:100%;
  margin:0;
}
.blocks-gallery-item .block-editor-media-placeholder .components-placeholder__label{
  display:flex;
}

.wp-block-gallery ul.blocks-gallery-grid{
  margin:0;
  padding:0;
}

@media (min-width:600px){
  .wp-block-update-gallery-modal{
    max-width:480px;
  }
}

.wp-block-update-gallery-modal-buttons{
  display:flex;
  gap:12px;
  justify-content:flex-end;
}