/*--------------------------------------------------------------
# Mobile Menu
--------------------------------------------------------------*/
.menu-toggle,
.mobile-bar-items,
.sidebar-nav-mobile {
	display: none;
}

.menu-toggle {
	padding: 0 20px;
	line-height: 60px;
	margin: 0;
	font-weight: normal;
	text-transform: none;
	font-size: 15px;
	cursor: pointer;
}

button.menu-toggle {
	background-color: transparent;
	width: 100%;
	border: 0;
	text-align: center;
}

button.menu-toggle:hover,
button.menu-toggle:active,
button.menu-toggle:focus {
	background-color: transparent;
}

.menu-toggle .mobile-menu {
	padding-left: 3px;
}

.menu-toggle .gp-icon + .mobile-menu {
	padding-left: 9px;
}

.menu-toggle .mobile-menu:empty {
	display: none;
}

.nav-search-enabled .main-navigation .menu-toggle {
	text-align: left;
}

.mobile-bar-items {
	display: none;
	position: absolute;
	right: 0;
	top: 0;
	z-index: 21;
	list-style-type: none;
}

.mobile-bar-items a {
	display: inline-block;
}

nav.toggled ul ul.sub-menu {
	width: 100%;
}

.dropdown-hover .main-navigation.toggled ul li:hover > ul,
.dropdown-hover .main-navigation.toggled ul li.sfHover > ul {
	transition-delay: 0s;
}

.toggled .menu-item-has-children .dropdown-menu-toggle {
	padding-left: 20px;
}

.main-navigation.toggled ul ul {
	transition: 0s;
	visibility: hidden;
}

.main-navigation.toggled .main-nav > ul {
	display: block;
}

.main-navigation.toggled .main-nav ul ul.toggled-on {
	position: relative;
	top: 0;
	left: auto !important;
	right: auto !important;
	width: 100%;
	pointer-events: auto;
	height: auto;
	opacity: 1;
	display: block;
	visibility: visible;
	float: none;
}

.main-navigation.toggled .main-nav li {
	float: none;
	clear: both;
	display: block;
	text-align: left;
}

.main-navigation.toggled .main-nav li.hide-on-mobile {
	display: none !important;
}

.main-navigation.toggled .menu-item-has-children .dropdown-menu-toggle {
	float: right;
}

.main-navigation.toggled .menu li.search-item {
	display: none !important;
}

.main-navigation.toggled .sf-menu > li.menu-item-float-right {
	float: none;
	display: inline-block;
}

/*--------------------------------------------------------------
# Breakpoint (768px)
--------------------------------------------------------------*/
@media (max-width: 768px) {
	/*--------------------------------------------------------------
	## Links
	--------------------------------------------------------------*/
	a, body, button, input, select, textarea {
		transition: all 0s ease-in-out;
	}
	/*--------------------------------------------------------------
	## Top Bar
	--------------------------------------------------------------*/
	.top-bar.top-bar-align-left,
	.top-bar.top-bar-align-right {
		text-align: center;
	}
	.top-bar .widget {
		float: none !important;
		margin: 0 10px !important;
	}
	.top-bar .widget_nav_menu li {
		float: none;
		display: inline-block;
		padding: 5px 0;
	}
	.footer-bar .widget_nav_menu li:first-child {
		margin-left: 10px;
	}
	.footer-bar .widget_nav_menu li:last-child {
		margin-right: 10px;
	}
	/*--------------------------------------------------------------
	## Header
	--------------------------------------------------------------*/
	.inside-header > *:not(:last-child):not(.main-navigation) {
		margin-bottom: 20px;
	}
	.site-header,
	.header-aligned-right .site-header {
		text-align: center;
	}
	.header-widget {
		float: none;
		max-width: 100%;
		text-align: center;
	}
	/*--------------------------------------------------------------
	## Content Area
	--------------------------------------------------------------*/
	.sidebar,
	.content-area,
	.inside-footer-widgets > div {
		float: none;
		width: 100%;
		left: 0;
		right: 0;
	}
	.site-main {
		margin-left: 0 !important;
		margin-right: 0 !important;
	}
	body:not(.no-sidebar) .site-main {
		margin-bottom: 0 !important;
	}
	.one-container .sidebar {
		margin-top: 40px;
	}
	.separate-containers #left-sidebar + #right-sidebar .inside-right-sidebar {
		margin-top: 0;
	}
	.both-right.separate-containers .inside-left-sidebar,
	.both-left.separate-containers .inside-left-sidebar,
	.both-right.separate-containers .inside-right-sidebar,
	.both-left.separate-containers .inside-right-sidebar {
		margin-right: 0;
		margin-left: 0;
	}
	.alignleft,
	.alignright {
		float: none;
		display: block;
		margin-left: auto;
		margin-right: auto;
	}
	.post-image-aligned-left .post-image,
	.post-image-aligned-right .post-image {
		float: none;
		margin: 2em 0;
		text-align: center;
	}
	.comment .children {
		padding-left: 10px;
		margin-left: 0;
	}
	.edd_download {
		display: block;
		float: none !important;
		margin-bottom: 1.5em;
		width: 100% !important;
	}
	.entry-meta {
		font-size: inherit;
	}
	.entry-meta a {
		line-height: 1.8em;
	}
	/*--------------------------------------------------------------
	## Footer
	--------------------------------------------------------------*/
	.site-info {
		text-align: center;
	}
	.copyright-bar {
		float: none !important;
		text-align: center !important;
	}
	.footer-bar {
		float: none !important;
		text-align: center !important;
		margin-bottom: 20px;
	}
	.footer-bar .widget_nav_menu li {
		float: none;
		display: inline-block;
		padding: 5px 0;
	}
	.inside-footer-widgets > div:not(:last-child) {
		margin-bottom: 40px;
	}
	.site-footer .footer-widgets .footer-widgets-container .inside-footer-widgets {
		margin: 0;
	}
	.site-footer .footer-widgets .footer-widgets-container .inner-padding {
		padding: 0;
	}
}
