:root{
  --wp-block-synced-color:#7a00df;
  --wp-block-synced-color--rgb:122, 0, 223;
  --wp-bound-block-color:var(--wp-block-synced-color);
  --wp-editor-canvas-background:#ddd;
  --wp-admin-theme-color:#007cba;
  --wp-admin-theme-color--rgb:0, 124, 186;
  --wp-admin-theme-color-darker-10:#006ba1;
  --wp-admin-theme-color-darker-10--rgb:0, 107, 160.5;
  --wp-admin-theme-color-darker-20:#005a87;
  --wp-admin-theme-color-darker-20--rgb:0, 90, 135;
  --wp-admin-border-width-focus:2px;
}
@media (min-resolution:192dpi){
  :root{
    --wp-admin-border-width-focus:1.5px;
  }
}

.patterns-menu-items__convert-modal{
  z-index:1000001;
}
.patterns-menu-items__convert-modal [role=dialog]>[role=document]{
  width:350px;
}
.patterns-menu-items__convert-modal .patterns-menu-items__convert-modal-categories{
  position:relative;
}
.patterns-menu-items__convert-modal .components-form-token-field__suggestions-list:not(:empty){
  background-color:#fff;
  border:1px solid var(--wp-admin-theme-color);
  border-bottom-left-radius:2px;
  border-bottom-right-radius:2px;
  box-shadow:0 0 .5px .5px var(--wp-admin-theme-color);
  box-sizing:border-box;
  max-height:96px;
  min-width:auto;
  position:absolute;
  right:-1px;
  width:calc(100% + 2px);
  z-index:1;
}

.patterns-create-modal__name-input input[type=text]{
  margin:0;
}

.patterns-rename-pattern-category-modal__validation-message{
  color:#cc1818;
}
@media (min-width:782px){
  .patterns-rename-pattern-category-modal__validation-message{
    width:320px;
  }
}

.pattern-overrides-control__allow-overrides-button{
  justify-content:center;
  width:100%;
}

.patterns-pattern-overrides-toolbar-indicator__popover .components-popover__content{
  min-width:260px;
  padding:16px;
}

.patterns-pattern-overrides-toolbar-indicator .patterns-pattern-overrides-toolbar-indicator-icon.has-colors svg{
  fill:var(--wp-block-synced-color);
}

.editor-collapsible-block-toolbar .patterns-pattern-overrides-toolbar-indicator{
  height:32px;
}