.components-base-control__help{margin-bottom:0;margin-top:2px}.components-base-control__label{display:block;margin-bottom:10px}.generate-customize-control-wrapper{display:flex}.generate-customize-control-wrapper[data-wrapper-type=color]>div:first-child{flex-grow:1}.generate-customize-control-wrapper[data-wrapper-type=color]>div:not(:first-child):not(:empty){margin-left:5px}.generate-customize-control-wrapper[data-wrapper-type=two-col]>div{flex-basis:calc(50% - 5px)}.generate-customize-control-wrapper[data-wrapper-type=two-col]>div:nth-child(odd){margin-right:5px}.generate-customize-control-wrapper[data-wrapper-type=two-col]>div:nth-child(2n){margin-left:5px}.generate-customize-control--popover>.components-popover__content{box-sizing:border-box;padding:15px;width:280px}.generate-customize-control--popover .components-base-control:not(:last-child){margin-bottom:15px}.customize-control[data-toggleid]{display:none}#customize-control-generate_settings-google_font_display{display:flex;flex-direction:column;margin-top:10px}#customize-control-generate_settings-google_font_display .description{margin-bottom:0;margin-top:5px;order:10}
.generate-component-color-picker{padding:5px 15px 5px 5px}
.generate-component-color-picker .components-color-picker{box-sizing:border-box}.generate-component-color-picker .components-color-picker__inputs-wrapper{display:none}.generate-component-color-picker .react-colorful{width:100%!important}.generate-component-color-picker .react-colorful .react-colorful__pointer{height:20px;width:20px}.generate-component-color-picker .react-colorful .react-colorful__saturation{height:150px}.generate-component-color-picker .generate-color-input-wrapper{display:flex;padding:0}.generate-component-color-picker .generate-color-input-wrapper .generate-color-input{flex-grow:1}.generate-component-color-picker .generate-color-input-wrapper .components-color-clear-color{margin-left:5px}.generate-component-color-picker .generate-color-input-wrapper input{margin-right:5px}.generate-component-color-picker .generate-color-input-wrapper .components-base-control__field,.generate-component-color-picker>.components-base-control:first-child{margin-bottom:0}.generate-component-color-picker .components-color-picker__inputs-wrapper{min-width:auto}.generate-component-color-picker .generate-component-color-picker-palette{padding:16px 0 0}.generate-component-color-picker .generate-component-color-picker-palette .components-circular-option-picker{display:flex;flex-wrap:wrap}.generate-component-color-picker .generate-component-color-picker-palette .components-circular-option-picker .components-circular-option-picker__swatches{display:flex;flex-wrap:wrap;gap:6px}.generate-component-color-picker .components-color-palette,.generate-component-color-picker .generate-component-color-picker-palette .components-circular-option-picker .components-circular-option-picker__swatches .components-circular-option-picker__option-wrapper{margin:0}.generate-component-color-picker .components-color-picker{padding:5px;width:100%}.generate-component-color-picker .components-color-picker__body{padding-bottom:0}.generate-component-color-picker .components-popover__content{box-sizing:border-box;padding:10px;width:295px}.generate-component-color-picker .components-color-clear-color{height:auto}.generate-component-color-picker .components-circular-option-picker__option.is-pressed+svg{fill:#fff;background:#000;transform:scale(.6)}@media screen and (max-width:1666px){.generate-component-color-picker .components-popover__content{width:265px}}.generate-customize-control-wrapper{display:flex}.generate-customize-control-wrapper.generate-customize-color-control-wrapper>div:first-child{flex-grow:1}.generate-customize-control-wrapper.generate-customize-color-control-wrapper>div:not(:last-child){margin-right:5px}.generate-component-color-picker-wrapper>.components-base-control__field{align-items:center;display:flex;justify-content:space-between;position:relative}.generate-component-color-picker-wrapper>.components-base-control__field .components-color-palette__item-wrapper{margin:0}.generate-color-picker-area button,.generate-component-color-picker-palette button{height:28px;position:relative;width:28px}.generate-color-picker-area button:hover,.generate-component-color-picker-palette button:hover{background-color:inherit}.generate-color-picker-area button:focus:after,.generate-component-color-picker-palette button:focus:after{border:0;box-shadow:inset 0 0 0 2px #757575;height:28px;left:0;top:0;transform:none;width:28px}.generate-customize-control--popover .components-color-picker{box-sizing:border-box}.generate-customize-control--popover .components-color-picker__inputs-wrapper{display:none}.generate-customize-control--popover>.components-base-control:first-child{margin-bottom:0}.generate-customize-control--popover .components-color-picker__inputs-wrapper{min-width:auto}.generate-customize-control--popover .components-color-picker{padding:5px}.generate-customize-control--popover .components-color-picker__body{padding-bottom:0}.generate-customize-control--popover .components-color-clear-color{height:auto}.generate-component-color-picker[data-x-axis=left] .components-popover__content{margin-right:-35px!important}.generate-color-input--icon{align-items:center;border:1px solid;border-bottom-left-radius:3px;border-right:0;border-top-left-radius:3px;display:flex;justify-content:center;padding:5px}.generate-color-input--icon svg{height:1em;transform:scale(1.3);width:1em}.generate-color-option-area{padding:16px 0 0}.generate-color-input--css-var-name-wrapper{position:relative}.generate-color-input--css-var-name-wrapper button{bottom:0;height:auto;min-height:30px;padding:0 8px;position:absolute;right:0}.generate-color-input--css-var-name-wrapper button svg{fill:none;height:1em;width:1em}
.generate-font-manager--item{margin-bottom:10px}.generate-font-manager--item .generate-font-manager--header{align-items:center;display:flex}.generate-font-manager--item .generate-font-manager--header .generate-font-manager--label{flex-grow:1;overflow:hidden;padding-left:0;text-overflow:ellipsis;white-space:nowrap}.generate-font-manager--item .generate-font-manager--header .components-button:not(.generate-font-manager--label){align-items:center;background:#fff;border:1px solid #777;border-radius:100%;display:flex;flex-shrink:0;height:30px;justify-content:center;margin-left:5px;min-width:30px;padding:0;width:30px}.generate-font-manager--item .generate-font-manager--header .components-button:not(.generate-font-manager--label) svg{height:1em;margin-right:0;width:1em}.generate-font-manager--item .generate-font-manager--header .components-button:not(.generate-font-manager--label).generate-font-manager--open svg{fill:none}.generate-font-manager--item .generate-font-manager--options{margin-top:15px}.generate-font-manager--item .generate-font-manager--footer{border-top:1px solid #ddd;margin-top:15px;padding-top:15px}.generate-font-manager--item .generate-font-manager-google-font--field{margin-top:10px}.generate-font-manager--item .generate-font-manager--google-font-options{display:flex;flex-wrap:wrap;margin-top:15px}.generate-font-manager--item .generate-font-manager--google-font-options>div{flex-basis:calc(50% - 10px);margin-bottom:0}.generate-font-manager--item .generate-font-manager--google-font-options>div:nth-child(2n){margin-left:5px}.generate-font-manager--item .generate-font-manager--google-font-options>div:nth-child(odd){margin-right:5px}.generate-font-manager--item .generate-font-manager--google-font-options .components-base-control__field{margin-bottom:0!important}.generate-font-manager--item .generate-font-manager--select-options{display:flex;flex-wrap:wrap}.generate-font-manager--item .generate-font-manager--select-options>div{flex-basis:calc(50% - 5px)}.generate-font-manager--item .generate-font-manager--select-options>div:nth-child(2n){margin-left:5px}.generate-font-manager--item .generate-font-manager--select-options>div:nth-child(odd){margin-right:5px}.generate-font-manager--item .components-select-control__input--generate-fontfamily{margin-bottom:3px}.generate-font-manager--item .generate-advanced-select__menu{position:relative!important}.generate-font-manager-group{margin-bottom:20px;margin-top:10px}.generate-font-manager-group__label{color:#000;font-size:11px;margin-bottom:10px;margin-top:0;text-transform:uppercase}.generate-font-manager-group .generate-font-manager--item:last-child{margin-bottom:0}.generate-customize-control--font-dropdown{background:#fff;margin-top:10px;padding:15px;position:relative}.generate-customize-control--font-dropdown:before{border-color:transparent transparent #fff;border-style:solid;border-width:0 10px 10px;content:"";height:0;left:11px;position:absolute;top:-10px;width:0;z-index:10}.generate-customize-control--font-dropdown>.components-base-control:not(:last-child){margin-bottom:15px}.generate-customize-control--font-dropdown>.components-base-control:last-child .components-base-control__field{margin-bottom:0}
.generate-advanced-select__control{margin-bottom:12px}.generate-advanced-select__value-container{padding:0 6px!important}.generate-advanced-select__value-container>div{margin:0;padding:0}.generate-advanced-select__input input[type=text]:focus{box-shadow:none}.generate-advanced-select__option--is-selected{color:hsla(0,0%,100%,.5)!important}
.components-generate-units-control-header__units{align-items:center;display:flex;justify-content:space-between;margin-bottom:5px}.components-generate-control__units .components-generate-control-buttons__units button.components-button{background:#fff;border:0;border-radius:0!important;box-shadow:none!important;color:#929da7;font-size:10px;height:auto;line-height:20px;padding:0 5px;position:relative;text-align:center;text-shadow:none}.components-generate-control__units .components-generate-control-buttons__units button.components-button.is-primary{background:#fff!important;color:#000!important;cursor:default;font-weight:700;z-index:1}.generate-component-device-field[data-device=desktop],.generate-component-device-field[data-device=mobile],.generate-component-device-field[data-device=tablet]{display:none}.preview-desktop .generate-component-device-field[data-device=desktop]{display:block}.preview-desktop .components-generate-control__units button.components-generate-control-button__units--desktop{color:#000}.preview-tablet .generate-component-device-field[data-device=tablet]{display:block}.preview-tablet .components-generate-control__units button.components-generate-control-button__units--tablet{color:#000}.preview-mobile .generate-component-device-field[data-device=mobile]{display:block}.preview-mobile .components-generate-control__units button.components-generate-control-button__units--mobile{color:#000}
.gblocks-unit-control__disabled .gblocks-unit-control__input>.components-base-control{opacity:.5}.gblocks-unit-control__override-action{align-items:center;display:flex}.gblocks-unit-control__override-action button.components-button{height:20px;justify-content:center!important;min-width:20px;padding:0;width:20px}.gblocks-unit-control__override-action button.components-button.is-primary:focus:not(.disabled){box-shadow:0 0 0}.gblocks-unit-control__override-action button.components-button svg{margin:0!important;width:15px}.gblocks-unit-control__input{align-items:flex-start;display:flex;position:relative}.gblocks-unit-control__input .components-base-control:first-child{flex-grow:1}.gblocks-unit-control__input .components-base-control,.gblocks-unit-control__input .components-base-control__field{margin-bottom:0}.gblocks-unit-control__input--action{bottom:0;display:flex;gap:3px;position:absolute;right:5px;top:0}.gblocks-unit-control__input .gblocks-unit-control-units{align-items:center;display:flex;justify-content:center}.gblocks-unit-control__input .gblocks-unit-control-units button{align-items:center;border:1px solid rgba(0,0,0,.1);display:flex;font-size:10px;height:20px;justify-content:center;min-width:20px;padding:0 3px;width:auto}.gblocks-unit-control__input .gblocks-unit-control-units button:disabled{pointer-events:none}.gblocks-unit-control__input .gblocks-unit-control-units button.is-opened,.gblocks-unit-control__input .gblocks-unit-control-units button:hover{border-color:currentColor}.gblocks-unit-control__input .gblocks-unit-control-units button.is-opened{background:var(--wp-components-color-accent,var(--wp-admin-theme-color,#007cba));color:var(--wp-components-color-accent-inverted,#fff)}.gblocks-unit-control-popover .components-menu-group>div[role=group]{-ms-grid-columns:(1fr)[4];display:-ms-grid;display:grid;grid-template-columns:repeat(4,1fr)}.gblocks-unit-control-popover .components-menu-group>div[role=group] button{display:flex;justify-content:center;min-height:auto}.gblocks-unit-control-popover .components-menu-group>div[role=group] button .components-menu-item__item{font-size:11px;margin:0;min-width:auto}
.generate-color-manager-dnd-list{border:1px dashed #959595;display:flex;flex-wrap:wrap;padding:10px 5px 5px}.generate-color-manager-dnd-list .generate-color-manager-dnd-list-item{border-radius:50%;cursor:grab;display:inline-block;height:28px;margin:0 5px 5px 0;position:relative;vertical-align:top;width:28px}.generate-color-manager-dnd-list .generate-color-manager-dnd-list-item:before{background:url("data:image/svg+xml;charset=utf-8,%3Csvg width=%2728%27 height=%2728%27 fill=%27none%27 xmlns=%27http://www.w3.org/2000/svg%27%3E%3Cpath d=%27M6 8V6H4v2h2zm2 0V6h2v2H8zm2 8H8v-2h2v2zm2 0v-2h2v2h-2zm0 2v-2h-2v2H8v2h2v-2h2zm2 0v2h-2v-2h2zm2 0h-2v-2h2v2z%27 fill=%27%23555D65%27/%3E%3Cpath fill-rule=%27evenodd%27 clip-rule=%27evenodd%27 d=%27M18 18h2v-2h-2v-2h2v-2h-2v-2h2V8h-2v2h-2V8h-2v2h2v2h-2v2h2v2h2v2zm-2-4v-2h2v2h-2z%27 fill=%27%23555D65%27/%3E%3Cpath d=%27M18 18v2h-2v-2h2z%27 fill=%27%23555D65%27/%3E%3Cpath fill-rule=%27evenodd%27 clip-rule=%27evenodd%27 d=%27M8 10V8H6v2H4v2h2v2H4v2h2v2H4v2h2v2H4v2h2v-2h2v2h2v-2h2v2h2v-2h2v2h2v-2h2v2h2v-2h2v-2h-2v-2h2v-2h-2v-2h2v-2h-2v-2h2V8h-2V6h2V4h-2v2h-2V4h-2v2h-2V4h-2v2h-2V4h-2v2h2v2h-2v2H8zm0 2v-2H6v2h2zm2 0v-2h2v2h-2zm0 2v-2H8v2H6v2h2v2H6v2h2v2h2v-2h2v2h2v-2h2v2h2v-2h2v2h2v-2h-2v-2h2v-2h-2v-2h2v-2h-2v-2h2V8h-2V6h-2v2h-2V6h-2v2h-2v2h2v2h-2v2h-2z%27 fill=%27%23555D65%27/%3E%3Cpath fill-rule=%27evenodd%27 clip-rule=%27evenodd%27 d=%27M4 0H2v2H0v2h2v2H0v2h2v2H0v2h2v2H0v2h2v2H0v2h2v2H0v2h2v2H0v2h2v-2h2v2h2v-2h2v2h2v-2h2v2h2v-2h2v2h2v-2h2v2h2v-2h2v2h2v-2h2v-2h-2v-2h2v-2h-2v-2h2v-2h-2v-2h2v-2h-2v-2h2V8h-2V6h2V4h-2V2h2V0h-2v2h-2V0h-2v2h-2V0h-2v2h-2V0h-2v2h-2V0h-2v2H8V0H6v2H4V0zm0 4V2H2v2h2zm2 0V2h2v2H6zm0 2V4H4v2H2v2h2v2H2v2h2v2H2v2h2v2H2v2h2v2H2v2h2v2h2v-2h2v2h2v-2h2v2h2v-2h2v2h2v-2h2v2h2v-2h2v2h2v-2h-2v-2h2v-2h-2v-2h2v-2h-2v-2h2v-2h-2v-2h2V8h-2V6h2V4h-2V2h-2v2h-2V2h-2v2h-2V2h-2v2h-2V2h-2v2H8v2H6z%27 fill=%27%23555D65%27/%3E%3C/svg%3E");border-radius:50%;bottom:1px;content:"";left:1px;position:absolute;right:1px;top:1px;z-index:-1}.generate-color-manager-dnd-list .generate-color-manager-dnd-list-item span{border-radius:50%;display:block;height:28px;position:relative;width:28px}.generate-color-manager-dnd-list .generate-color-manager-dnd-list-item span:after{border:1px solid transparent;border-radius:50%;bottom:-1px;box-shadow:inset 0 0 0 1px rgba(0,0,0,.2);content:"";left:-1px;position:absolute;right:-1px;top:-1px}.generate-color-manager-wrapper{display:flex;flex-wrap:wrap}.generate-color-manager-wrapper .generate-color-manager--item{margin-bottom:5px;margin-right:5px;position:relative}.generate-color-manager-wrapper .generate-color-manager--item:last-child{margin-right:0}.generate-color-manager-wrapper .generate-color-manager--item .components-button.generate-color-manager--delete-color{background:rgba(0,0,0,.7);border-radius:100%;color:#fff;height:auto;min-width:0;opacity:0;padding:2px;pointer-events:none;position:absolute;right:-10px;top:-10px;transition:opacity .5s ease}.generate-color-manager-wrapper .generate-color-manager--item .components-button.generate-color-manager--delete-color svg{height:15px;margin-right:0!important;width:15px}.generate-color-manager-wrapper .generate-color-manager--item .components-button.generate-color-manager--delete-color:focus,.generate-color-manager-wrapper .generate-color-manager--item:hover .components-button.generate-color-manager--delete-color{opacity:1;pointer-events:auto}.generate-color-manager-wrapper .generate-color-manager--item .components-circular-option-picker__option-wrapper{margin:0}.generate-color-manager-wrapper .generate-color-manager--item .components-button.generate-color-manager--add-color{align-items:center;background:#fff;border:1px solid #777;border-radius:100%;display:flex;height:28px;justify-content:center;padding:0;width:28px}.generate-color-manager-wrapper .generate-color-manager--item .components-button.generate-color-manager--add-color svg{width:20px}
.generate-customize-control-title{display:flex;justify-content:space-between}.generate-customize-control-title button.generate-customize-control-title--label{font-size:14px;font-weight:500;height:auto;padding:0}.generate-customize-control-title button.generate-customize-control-title--toggle{align-items:center;background:#fff;border:1px solid #777;border-radius:100%;display:flex;height:28px;justify-content:center;padding:0;width:28px}.generate-customize-control-title button.generate-customize-control-title--toggle svg{fill:none;height:1em;width:1em}.generate-customize-control-title h3{font-size:14px!important;font-weight:500;margin-bottom:0}
