/*--------------------------------------------------------------
## Footer Widgets
--------------------------------------------------------------*/
.footer-widgets-container {
	padding: 40px;
}

.inside-footer-widgets {
	display: flex;
}

.inside-footer-widgets > div {
	flex: 1 1 0;
}

.site-footer .footer-widgets-container .inner-padding {
	padding: 0px 0px 0px 40px;
}

.site-footer .footer-widgets-container .inside-footer-widgets {
	margin-left: -40px;
}

/*--------------------------------------------------------------
## Top Bar
--------------------------------------------------------------*/
.top-bar {
	font-weight: normal;
	text-transform: none;
	font-size: 13px;
}

.top-bar .inside-top-bar {
	display: flex;
	align-items: center;
	flex-wrap: wrap;
}

.top-bar .inside-top-bar .widget {
	padding: 0;
	display: inline-block;
	margin-bottom: 0;
}

.top-bar .inside-top-bar .textwidget p:last-child {
	margin: 0;
}

.top-bar .widget-title {
	display: none;
}

.top-bar .widget {
	margin: 0 10px;
}

.top-bar .widget_nav_menu > div > ul {
	display: flex;
	align-items: center;
}

.top-bar .widget_nav_menu li {
	margin: 0 10px;
	padding: 0;
}

.top-bar .widget_nav_menu li:first-child {
	margin-left: 0;
}

.top-bar .widget_nav_menu li:last-child {
	margin-right: 0;
}

.top-bar .widget_nav_menu li ul {
	display: none;
}

.inside-top-bar {
	padding: 10px 40px;
}

div.top-bar .widget {
	margin-bottom: 0;
}

.top-bar-align-right .widget {
	margin-right: 0;
}

.top-bar-align-right .widget:first-child {
	margin-left: auto;
}

.top-bar-align-right .widget:nth-child(even) {
	order: -20;
}

.top-bar-align-right .widget:nth-child(2) {
	margin-left: 0;
}

.top-bar-align-left .widget {
	margin-left: 0;
}

.top-bar-align-left .widget:nth-child(odd) {
	order: -20;
}

.top-bar-align-left .widget:nth-child(2) {
	margin-left: auto;
}

.top-bar-align-left .widget:last-child {
	margin-right: 0;
}

.top-bar-align-center .widget:first-child {
	margin-left: auto;
}

.top-bar-align-center .widget:last-child {
	margin-right: auto;
}

.top-bar-align-center .widget:not(:first-child):not(:last-child) {
	margin: 0 5px;
}

/*--------------------------------------------------------------
## Footer Bar
--------------------------------------------------------------*/
.footer-bar-active .footer-bar .widget {
	padding: 0;
}

.footer-bar .widget_nav_menu > div > ul {
	display: flex;
	align-items: center;
	flex-wrap: wrap;
}

.footer-bar .widget_nav_menu li {
	margin: 0 10px;
	padding: 0;
}

.footer-bar .widget_nav_menu li:first-child {
	margin-left: 0;
}

.footer-bar .widget_nav_menu li:last-child {
	margin-right: 0;
}

.footer-bar .widget_nav_menu li ul {
	display: none;
}

.footer-bar .textwidget p:last-child {
	margin: 0;
}

.footer-bar .widget-title {
	display: none;
}

.footer-bar-align-right .copyright-bar {
	order: -20;
	margin-right: auto;
}

.footer-bar-align-left .copyright-bar {
	margin-left: auto;
}

.footer-bar-align-center .inside-site-info {
	flex-direction: column;
}

.footer-bar-align-center .footer-bar {
	margin-bottom: 10px;
}

.site-footer:not(.footer-bar-active) .copyright-bar {
	margin: 0 auto;
}

/*--------------------------------------------------------------
## Breakpoint (768px)
--------------------------------------------------------------*/
@media (max-width: 768px) {
	/*--------------------------------------------------------------
	## Top Bar
	--------------------------------------------------------------*/
	.top-bar .inside-top-bar {
		justify-content: center;
	}
	.top-bar .inside-top-bar > .widget {
		order: 1;
		margin: 0 10px;
	}
	.top-bar .inside-top-bar:first-child {
		margin-left: auto;
	}
	.top-bar .inside-top-bar:last-child {
		margin-right: auto;
	}
	.top-bar .widget_nav_menu li {
		padding: 5px 0;
	}
	.top-bar-align-center {
		text-align: center;
	}
	/*--------------------------------------------------------------
	## Footer
	--------------------------------------------------------------*/
	.inside-footer-widgets {
		flex-direction: column;
	}
	.inside-footer-widgets > div:not(:last-child) {
		margin-bottom: 40px;
	}
	.site-footer .footer-widgets .footer-widgets-container .inside-footer-widgets {
		margin: 0;
	}
	.site-footer .footer-widgets .footer-widgets-container .inner-padding {
		padding: 0;
	}
	.footer-bar-active .inside-site-info {
		flex-direction: column;
	}
	.footer-bar-active .footer-bar {
		margin-bottom: 10px;
	}
	.footer-bar .widget_nav_menu > div > ul {
		justify-content: center;
	}
	.footer-bar .widget_nav_menu li {
		padding: 5px 0;
	}
	.footer-bar .widget_nav_menu li:first-child {
		margin-left: 10px;
	}
	.footer-bar .widget_nav_menu li:last-child {
		margin-right: 10px;
	}
	.footer-bar-align-left .copyright-bar {
		margin-left: 0;
	}
	.footer-bar-align-right .copyright-bar {
		order: unset;
		margin-right: 0;
	}
}
